Build instructions for examples 
-------------------------------

1. clone the git repository: `git clone https://github.com/MultithreadCorner/MCBooster.git`
2. go to MCBooster directory: `cd MCBooster`
3. create a build directory: `mkdir build` 
4. cd build
5. `cmake ../`
6. `make`
